;+
;PROCEDURE:  wind_init
;PURPOSE:    Initializes system variables for themis.  Can be called from idl_startup to set
;            custom locations.
;

;
;HISTORY
; Written by Davin Larson
; 2006-12-16 KRB Can now be called from idl_startup to set paths using optional keywords.
;
;$LastChangedBy: davin-win $
;$LastChangedDate: 2007-07-13 17:25:08 -0700 (Fri, 13 Jul 2007) $
;$LastChangedRevision: 1102 $
;$URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/ssl_general/tags/tdas_3_02/missions/wind/wind_init.pro $
;-
pro wind_init, reset=reset, local_data_dir=local_data_dir, remote_data_dir=remote_data_dir

defsysv,'!wind',exists=exists
if not keyword_set(exists) then begin

   defsysv,'!wind',  file_retrieve(/structure_format)
endif

if keyword_set(reset) then !wind.init=0

if !wind.init ne 0 then return

!wind.remote_data_dir = 'http://themis.ssl.berkeley.edu/data/

caching = 1

   if !version.os_family  eq 'Windows' then begin
      if CACHing then begin
         ;;-->   Location of local cache for WINDOWS
         ;;      Edit the following line to point to a writeable directory.
  if file_test('E:/data/',/direc) then !wind.local_data_dir = 'E:/data/'  $
         else  !wind.local_data_dir = 'C:/data/'
         !wind.no_download = 0
      endif else begin
         ;;-->   Mount point of master data directory for WINDOWS
         ;;      E.g. At SSL, justice runs a read-only Samba server which
         ;;      provides direct access to //sprg.ssl.berkeley.edu/data/themis
         !wind.local_data_dir = '\\justice\data\'
         !wind.no_download = 1
      endelse

   endif

   if !version.os_family eq 'unix' then begin

      if caching then begin
         ;;-->  Location of local cache on your laptop for UNIX (or Mac)
         ;;     OR for desktops remote from SSL, this could be edited to
         ;;     point to a shared data area where many users can download
         ;;     data from the master data server.
         !wind.local_data_dir = '/disks/data/'
         !wind.no_download = 0
      endif else begin
         ;;-->  Location of NFS mount point of master data directory.
         !wind.local_data_dir = '/disks/data/'
         !wind.no_download = 1
      endelse

   endif


printdat,/values,!wind,varname='!wind

!wind.init = 1

end

